@@ -204,14 +204,15 @@ class Rotation(Quaternion):
         Scalar
         """
         other = Rotation(other)
-        angles = Scalar(
-            np.nan_to_num(np.arccos(2 * self.unit.dot(other.unit).data ** 2 - 1))
-        )
+        dp = self.unit.dot(other.unit).data
+        # Round because some dot products are slightly above 1
+        dp = np.round(dp, np.finfo(dp.dtype).precision)
+        angles = Scalar(np.nan_to_num(np.arccos(2 * dp ** 2 - 1)))
         return angles
 
-    def outer(self, other):
+    def outer(self, other, **kwargs):
         """Compute the outer product of this rotation and the other object."""
-        r = super().outer(other)
+        r = super().outer(other, **kwargs)
         if isinstance(r, Rotation):
             r.improper = np.logical_xor.outer(self.improper, other.improper)
         if isinstance(r, Vector3d):
@@ -330,21 +331,42 @@ class Rotation(Quaternion):
         euler : array-like
             Euler angles in radians in the Bunge convention.
         convention : str
-            Only "bunge" is supported for new data.
+            "bunge" or "MTEX"
         direction : str
-            "lab2crystal" or "crystal2lab".
+            "lab2crystal" or "crystal2lab", ignored if "MTEX" convention is in use
         """
-        conventions = ["bunge", "Krakow_Hielscher"]
-        if convention not in conventions:
-            raise ValueError(
-                f"The chosen convention is not one of the allowed options {conventions}"
-            )
         directions = ["lab2crystal", "crystal2lab"]
+        conventions = ["bunge", "mtex"]
+
+        # processing directions
         if direction not in directions:
             raise ValueError(
                 f"The chosen direction is not one of the allowed options {directions}"
             )
 
+        # processing the convention chosen
+
+        convention = convention.lower()
+
+        if convention == "krakow_hielscher":
+            # To be applied to the data found at:
+            # https://www.repository.cam.ac.uk/handle/1810/263510
+            warnings.warn(
+                "This method is deprecated and will be removed in v0.8 use 'MTEX' instead"
+            )
+            convention = "mtex"
+
+        if convention not in conventions:
+            raise ValueError(
+                f"The chosen convention is not one of the allowed options {conventions}"
+            )
+
+        if convention == "mtex":
+            # MTEX uses bunge but with lab2crystal referencing:
+            # see - https://mtex-toolbox.github.io/MTEXvsBungeConvention.html
+            # and orix issue #215
+            direction = "lab2crystal"
+
         euler = np.array(euler)
         if np.any(np.abs(euler) > 9):
             warnings.warn(
@@ -354,70 +376,41 @@ class Rotation(Quaternion):
         n = euler.shape[:-1]
         alpha, beta, gamma = euler[..., 0], euler[..., 1], euler[..., 2]
 
-        if convention == "Krakow_Hielscher":
-            # To be applied to the data found at:
-            # https://www.repository.cam.ac.uk/handle/1810/263510
-            alpha -= np.pi / 2
-            gamma -= 3 * np.pi / 2
-            zero = np.zeros(n)
-            qalpha = Quaternion(
-                np.stack((np.cos(alpha / 2), zero, zero, np.sin(alpha / 2)), axis=-1)
-            )
-            qbeta = Quaternion(
-                np.stack((np.cos(beta / 2), zero, np.sin(beta / 2), zero), axis=-1)
-            )
-            qgamma = Quaternion(
-                np.stack((np.cos(gamma / 2), zero, zero, np.sin(gamma / 2)), axis=-1)
-            )
-            data = qalpha * qbeta * qgamma
+        # Uses A.5 & A.6 from Modelling Simul. Mater. Sci. Eng. 23
+        # (2015) 083501
+        sigma = 0.5 * np.add(alpha, gamma)
+        delta = 0.5 * np.subtract(alpha, gamma)
+        c = np.cos(beta / 2)
+        s = np.sin(beta / 2)
 
-            rot = cls(data.data)
-            rot.improper = zero
-            return rot
-        elif convention == "bunge":
-            # Uses A.5 & A.6 from Modelling Simul. Mater. Sci. Eng. 23
-            # (2015) 083501
-            sigma = 0.5 * np.add(alpha, gamma)
-            delta = 0.5 * np.subtract(alpha, gamma)
-            c = np.cos(beta / 2)
-            s = np.sin(beta / 2)
+        # Using P = 1 from A.6
+        q = np.zeros(n + (4,))
+        q[..., 0] = c * np.cos(sigma)
+        q[..., 1] = -s * np.cos(delta)
+        q[..., 2] = -s * np.sin(delta)
+        q[..., 3] = -c * np.sin(sigma)
 
-            # Using P = 1 from A.6
-            q = np.zeros(n + (4,))
-            q[..., 0] = c * np.cos(sigma)
-            q[..., 1] = -s * np.cos(delta)
-            q[..., 2] = -s * np.sin(delta)
-            q[..., 3] = -c * np.sin(sigma)
+        for i in [1, 2, 3, 0]:  # flip the zero element last
+            q[..., i] = np.where(q[..., 0] < 0, -q[..., i], q[..., i])
 
-            for i in [1, 2, 3, 0]:  # flip the zero element last
-                q[..., i] = np.where(q[..., 0] < 0, -q[..., i], q[..., i])
+        data = Quaternion(q)
 
-            data = Quaternion(q)
+        if direction == "lab2crystal":
+            data = ~data
 
-            if direction == "lab2crystal":
-                data = ~data
-
-            rot = cls(data.data)
-            rot.improper = np.zeros((n))
-            return rot
+        rot = cls(data.data)
+        rot.improper = np.zeros((n))
+        return rot
 
     def to_matrix(self):
-        """Rotations as orientation matrices [Rowenhorst2015]_.
+        """Rotations as orientation matrices
+        :cite:`rowenhorst2015consistent`.
 
         Returns
         -------
         ndarray
             Array of orientation matrices.
 
-        References
-        ----------
-        .. [Rowenhorst2015] D. Rowenhorst, A. D. Rollett, G. S. Rohrer,
-            M. Groeber, M. Jackson, P. J. Konijnenberg, M. De Graef,
-            "Consistent representations of and conversions between 3D
-            rotations," *Modelling and Simulation in Materials Science
-            and Engineering* **23** (2015), doi:
-            https://doi.org/10.1088/0965-0393/23/8/083501
-
         Examples
         --------
         >>> import numpy as np
@@ -457,7 +450,7 @@ class Rotation(Quaternion):
     @classmethod
     def from_matrix(cls, matrix):
         """Creates rotations from orientation matrices
-        [Rowenhorst2015]_.
+        :cite:`rowenhorst2015consistent`.
 
         Parameters
         ----------
@@ -467,7 +460,7 @@ class Rotation(Quaternion):
         Examples
         --------
         >>> import numpy as np
-        >>> from orix.quaternion.rotation import Rotation
+        >>> from orix.quaternion import Rotation
         >>> r = Rotation.from_matrix(np.eye(3))
         >>> np.allclose(r.data, [1, 0, 0, 0])
         True
@@ -512,18 +505,18 @@ class Rotation(Quaternion):
 
     @property
     def axis(self):
-        """Vector3d : the axis of rotation."""
+        """The axis of rotation as a :class:`~orix.vector.Vector3d`."""
         axis = Vector3d(np.stack((self.b.data, self.c.data, self.d.data), axis=-1))
-        axis[self.a.data < -1e-6] = -axis[self.a.data < -1e-6]
-        axis[axis.norm.data == 0] = Vector3d.zvector() * np.sign(
-            self.a[axis.norm.data == 0].data
-        )
+        a_is_zero = self.a.data < -1e-6
+        axis[a_is_zero] = -axis[a_is_zero]
+        norm_is_zero = axis.norm.data == 0
+        axis[norm_is_zero] = Vector3d.zvector() * np.sign(self.a[norm_is_zero].data)
         axis.data = axis.data / axis.norm.data[..., np.newaxis]
         return axis
 
     @property
     def angle(self):
-        """Scalar : the angle of rotation."""
+        """The angle of rotation as a :class:`~orix.scalar.Scalar`."""
         return Scalar(2 * np.nan_to_num(np.arccos(np.abs(self.a.data))))
 
     @classmethod
@@ -581,6 +574,29 @@ class Rotation(Quaternion):
         r.improper = self.improper
         return r
 
+    def _outer_dask(self, other, chunk_size=20):
+        """Compute the product of every rotation in this instance to
+        every rotation in another instance, returned as a Dask array.
+
+        Parameters
+        ----------
+        other : orix.quaternion.Rotation
+        chunk_size : int, optional
+            Number of rotations per axis in each rotation instance to
+            include in each iteration of the computation. Default is 20.
+
+        Returns
+        -------
+        dask.array.Array
+
+        Notes
+        -----
+        To get a new rotation from the returned array `rarr`, do
+        `r = Rotation(rarr.compute())`.
+        """
+        r = super()._outer_dask(other, chunk_size=chunk_size)
+        return r
+
 
 def von_mises(x, alpha, reference=Rotation((1, 0, 0, 0))):
     r"""A vastly simplified Von Mises-Fisher distribution calculation.
@@ -606,5 +622,5 @@ def von_mises(x, alpha, reference=Rotation((1, 0, 0, 0))):
     -------
     numpy.ndarray
     """
-    angle = x.angle_with(reference)
+    angle = Rotation(x).angle_with(reference)
     return np.exp(2 * alpha * np.cos(angle.data)) / hyp0f1(1.5, alpha ** 2)
