@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2020 the orix developers
+# Copyright 2018-2021 the orix developers
 #
 # This file is part of orix.
 #
@@ -16,10 +16,10 @@
 # You should have received a copy of the GNU General Public License
 # along with orix.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Module for generating grids in orientation spaces."""
+"""Generation of grids in orientation space."""
 
 from orix.sampling.sample_generators import get_sample_fundamental, get_sample_local
-from orix.sampling.sampling_utils import uniform_SO3_sample
+from orix.sampling.SO3_sampling import uniform_SO3_sample
 
 # Lists what will be imported when calling "from orix.sampling import *"
 __all__ = [
