@@ -306,6 +306,31 @@ class TestMiller:
         assert np.allclose(m6.hkl, v.reshape(shape2 + (3,)))
         assert m1._compatible_with(m6)  # Phase carries over
 
+    def test_transpose(self):
+        # test 2d
+        shape = (11, 5)
+        v = np.random.randint(-5, 5, shape + (3,))
+
+        m1 = Miller(hkl=v, phase=TETRAGONAL_PHASE)
+        m2 = m1.transpose()
+
+        assert m1.shape == m2.shape[::-1]
+        assert m1.phase == m2.phase
+
+        # test 2d
+        shape = (11, 5, 4)
+        v = np.random.randint(-5, 5, shape + (3,))
+
+        m1 = Miller(hkl=v, phase=TETRAGONAL_PHASE)
+        m2 = m1.transpose(0, 2, 1)
+
+        assert m2.shape == (11, 4, 5)
+        assert m1.phase == m2.phase
+
+        m2 = m1.transpose(1, 0, 2)
+        assert m2.shape == (5, 11, 4)
+        assert m1.phase == m2.phase
+
 
 class TestMillerBravais:
     def test_uvw2UVTW(self):
