@@ -604,6 +604,28 @@ class Miller(Vector3d):
         m.coordinate_format = self.coordinate_format
         return m
 
+    def transpose(self, *axes):
+        """Returns a new Miller object containing the same data transposed.
+
+        If ndim is originally 2, then order may be undefined.
+        In this case the first two dimensions will be transposed.
+
+        Parameters
+        ----------
+        axes : int, optional
+            The transposed axes order. Only navigation axes need to be defined.
+            May be undefined if self only contains two navigation dimensions.
+
+        Returns
+        -------
+        Miller :
+            A transposed Miller instance of the object.
+
+        """
+        m = self.__class__(xyz=super().transpose(*axes).data, phase=self.phase)
+        m.coordinate_format = self.coordinate_format
+        return m
+
     def get_nearest(self):
         """NotImplemented."""
         return NotImplemented
